(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    123138,       2607]
NotebookOptionsPosition[    118904,       2465]
NotebookOutlinePosition[    119665,       2491]
CellTagsIndexPosition[    119622,       2488]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Swinging Blind Jugger dynamics", "Title",
 CellChangeTimes->{{3.5608447892880087`*^9, 3.560844804576883*^9}}],

Cell["\<\
by Flavio Fontana ffontana@student.ethz.ch\
\>", "Text",
 CellChangeTimes->{{3.5608448115282803`*^9, 3.5608448328875017`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
 CellChangeTimes->{{3.560678650691608*^9, 3.560678658812619*^9}}],

Cell[TextData[{
 "This Notebook derives the system dynamics of the Swinging Blind Juggler \
(SBJ), show in the following figure. \nRev\n\n\n",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsvQl8XMWVt803CWTIhLwhMBMCSYAMCQxDIAFsMKvZlzDAhLB8WVjClsAb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     "], {{0, 491}, {451, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   BaseStyle->"ImageGraphics",
   ImageSize->Automatic,
   ImageSizeRaw->{451, 491},
   PlotRange->{{0, 451}, {0, 491}}]], "Input"]
}], "Text",
 CellChangeTimes->{{3.5606786650736284`*^9, 3.560678709740691*^9}, {
  3.5606788768812537`*^9, 3.560678934855338*^9}, {3.5607818471129217`*^9, 
  3.5607818774286556`*^9}, {3.5608446080086393`*^9, 3.5608446711032486`*^9}}],

Cell["\<\
For modeling the SBJ dynamics the following reduced three body model was used.\
\>", "Text",
 CellChangeTimes->{{3.560678949227358*^9, 3.5606789703593884`*^9}, 
   3.5608446441517067`*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3QdYFOfaN3C/5Jz3PTlvzHf8Tt4YTxIbSO8gXXoRsKHSiwiKBZAiRUGk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    "], {{0, 276}, {404, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{404, 276},
  PlotRange->{{0, 404}, {0, 276}}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clean Up", "Section",
 CellChangeTimes->{{3.553917258287663*^9, 3.553917317356746*^9}, {
  3.5587008680100646`*^9, 3.558700869090066*^9}, {3.560677964820761*^9, 
  3.560677966481764*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.55391726304867*^9, 3.5539172795526934`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derive the Energy for each body", "Section",
 CellChangeTimes->{{3.553916674414507*^9, 3.553916717079567*^9}, {
  3.5539167785699778`*^9, 3.553916800714009*^9}, {3.5539168398890653`*^9, 
  3.5539168401490655`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Energy for K1 / pendulum
r1\tlocation of the CG of the pendulum
v1\tvelocity of the CG of the pendulum
m1\tmass of the pendulum
l1\tdistance to cog
l0\tlength of the pendulum
I1\tMOI for a rotation around the CG for the pendulum\
\>", "Subsubsection",
 CellChangeTimes->{{3.5539168205860367`*^9, 3.5539168508010807`*^9}, {
  3.558434734166483*^9, 3.5584347656492834`*^9}, {3.5584348042944937`*^9, 
  3.5584348149531035`*^9}, {3.560678034212859*^9, 3.5606780523068857`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "l1"}], "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"phi", "[", "t", "]"}], "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"-", "l1"}], "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"phi", "[", "t", "]"}], "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.553916853151084*^9, 3.5539168645631*^9}, 
   3.5606780890029373`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1", " ", "=", " ", 
  RowBox[{"D", "[", 
   RowBox[{"r1", ",", " ", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5539168707941084`*^9, 3.5539168707941084`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "l1"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["phi", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], ",", "0", ",", 
   RowBox[{"l1", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["phi", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.558674049693698*^9, 3.5586751228610797`*^9, 
  3.5586752429629493`*^9, 3.5586760317190638`*^9, 3.5586854249323244`*^9, 
  3.5587009585012274`*^9, 3.5587530092106304`*^9, 3.5587598955345054`*^9, 
  3.558762539200714*^9, 3.5587630553402357`*^9, 3.558776054636753*^9, 
  3.558779956749941*^9, 3.5588459099682493`*^9, 3.5606780840619307`*^9, 
  3.5606781227709866`*^9, 3.5606784150984015`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ekin1", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "m1", "*", 
     RowBox[{"v1", ".", "v1"}]}], "+", 
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "I1", "*", 
     RowBox[{
      RowBox[{
       SuperscriptBox["phi", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "^", "2"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{"I1", "+", 
    RowBox[{
     SuperscriptBox["l1", "2"], " ", "m1"}]}], ")"}], " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["phi", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{
  3.5539168785551195`*^9, 3.553917170896538*^9, 3.553917412707899*^9, 
   3.5540215981316495`*^9, 3.5541892052811413`*^9, 3.5565250645798187`*^9, 
   3.5581713502867866`*^9, 3.558260287143684*^9, 3.5582618129619555`*^9, 
   3.558261937856099*^9, {3.558262436602626*^9, 3.558262440065824*^9}, 
   3.5584282365558405`*^9, 3.5584300101662855`*^9, 3.5584302642578187`*^9, 
   3.5584313623946285`*^9, 3.5584327192622366`*^9, {3.5584350471633854`*^9, 
   3.558435081740363*^9}, 3.5584358396477127`*^9, 3.558435915668061*^9, 
   3.5584361286432424`*^9, 3.558436162575183*^9, 3.5586691342125487`*^9, 
   3.5586705025208116`*^9, 3.558671683809377*^9, 3.5586736966355047`*^9, 
   3.5586740500137167`*^9, 3.558675122989087*^9, 3.5586752433369703`*^9, 
   3.558676031822069*^9, 3.558685425041331*^9, 3.5587009585912275`*^9, 
   3.5587530093466377`*^9, 3.5587598956245103`*^9, 3.558762539351723*^9, 
   3.5587630554222403`*^9, 3.558776054724758*^9, 3.558779956867948*^9, 
   3.5588459101022573`*^9, 3.5606780841819305`*^9, 3.5606781228109865`*^9, 
   3.5606784151384015`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Epot1", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"-", "m1"}], "*", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", " ", "0", ",", " ", 
       RowBox[{"-", "g"}]}], "}"}], ".", "r1"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.55391688622513*^9, 3.55391688622513*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "g"}], " ", "l1", " ", "m1", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"phi", "[", "t", "]"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.5539168876851325`*^9, 3.5539171709365377`*^9, 3.553917412757899*^9, 
   3.554021598176652*^9, 3.554189205326144*^9, 3.5565250646168213`*^9, 
   3.5581713503257885`*^9, 3.558260287194687*^9, 3.558261813015959*^9, 
   3.5582619379281034`*^9, {3.5582624366806307`*^9, 3.558262440192831*^9}, 
   3.5584282366028433`*^9, 3.5584300102172885`*^9, 3.5584302643198223`*^9, 
   3.558431362457632*^9, 3.5584327193282404`*^9, {3.558435047224389*^9, 
   3.558435081797366*^9}, 3.558435839692715*^9, 3.5584359157820673`*^9, 
   3.5584361287032456`*^9, 3.558436162623186*^9, 3.558669134267552*^9, 
   3.5586705025688143`*^9, 3.5586716838613806`*^9, 3.558673696683507*^9, 
   3.558674050059719*^9, 3.5586751230320897`*^9, 3.5586752433949738`*^9, 
   3.5586760320270815`*^9, 3.5586854251953397`*^9, 3.5587009586412277`*^9, 
   3.558753009401641*^9, 3.5587598956745133`*^9, 3.5587625393927255`*^9, 
   3.558763055458243*^9, 3.55877605475976*^9, 3.5587799569079504`*^9, 
   3.55884591015326*^9, 3.5606780842119308`*^9, 3.5606781228409863`*^9, 
   3.5606784151884017`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Energy for K2 / the non moving but rotating parts. (stator lower linkage ... \
..)
r2\tlocation of the CG of the body
v2\tvelocity of the CG of the body
m2\tmass 
l2\tdistance to cog
I2\tMOI for a rotation around the CG for the body
l0 \tpendulum length\
\>", "Subsubsection",
 CellChangeTimes->{{3.5539170183953176`*^9, 3.553917025745328*^9}, {
  3.5584347729006987`*^9, 3.5584347998332386`*^9}, {3.5606780578178935`*^9, 
  3.5606780594188957`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "l0"}], "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"l2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"upsilon", "[", "t", "]"}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", "0", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "l0"}], "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"l2", "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"upsilon", "[", "t", "]"}], "]"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.5606781061459618`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v2", "=", 
  RowBox[{"D", "[", 
   RowBox[{"r2", ",", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "l0"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["upsilon", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"l0", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"l2", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["upsilon", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.55391704845936*^9, 3.553917171006538*^9, 3.5539174128378987`*^9, 
   3.554021598278658*^9, 3.5541892054121494`*^9, 3.5565250647138267`*^9, 
   3.5581713504087934`*^9, 3.558260287304693*^9, 3.5582618131849685`*^9, 
   3.5582619382171197`*^9, {3.5582624368096375`*^9, 3.5582624403928423`*^9}, 
   3.558428236700849*^9, 3.5584300103232946`*^9, 3.5584302644258285`*^9, 
   3.5584313625666385`*^9, 3.558432719455248*^9, {3.5584350473413954`*^9, 
   3.5584350819093723`*^9}, 3.5584358399437294`*^9, 3.5584359160130806`*^9, 
   3.5584361288212523`*^9, 3.5584361627401924`*^9, 3.5586691343675575`*^9, 
   3.558670502827829*^9, 3.5586716839563856`*^9, 3.5586736967875133`*^9, 
   3.5586740501727257`*^9, 3.5586751231300955`*^9, 3.5586752435159807`*^9, 
   3.5586760321880903`*^9, 3.558685425306346*^9, 3.558700958741228*^9, 
   3.5587530095096474`*^9, 3.558759895772519*^9, 3.5587625394847307`*^9, 
   3.5587630555432477`*^9, 3.558776054847765*^9, 3.5587799569969554`*^9, 
   3.5588459102412653`*^9, 3.560678084281931*^9, 3.5606781229109864`*^9, 
   3.5606784152484016`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ekin2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "m2", "*", 
     RowBox[{"v2", ".", "v2"}]}], "+", 
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "I2", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "'"}], "[", "t", "]"}], "^", "2"}]}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["l0", "2"], " ", "m2", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["phi", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", "l0", " ", "l2", " ", "m2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"phi", "[", "t", "]"}], "-", 
       RowBox[{"upsilon", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["upsilon", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"I2", "+", 
       RowBox[{
        SuperscriptBox["l2", "2"], " ", "m2"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["upsilon", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.553917054070368*^9, 3.553917171116538*^9, 3.553917412937899*^9, 
   3.5540215983916645`*^9, 3.5541892055221553`*^9, 3.556525064819833*^9, 
   3.5581713505208*^9, 3.558260287363696*^9, 3.5582618133249764`*^9, 
   3.558261938449133*^9, {3.558262436870641*^9, 3.5582624405328503`*^9}, 
   3.558428236807855*^9, 3.558430010383298*^9, 3.558430264474831*^9, 
   3.558431362804652*^9, 3.5584327197132626`*^9, {3.5584350474003987`*^9, 
   3.5584350819763765`*^9}, 3.558435840084738*^9, 3.558435916147088*^9, 
   3.5584361289492598`*^9, 3.558436162802196*^9, 3.558669134496565*^9, 
   3.558670502952836*^9, 3.558671684080393*^9, 3.5586736968345156`*^9, 
   3.5586740502937326`*^9, 3.558675123249102*^9, 3.5586752437249928`*^9, 
   3.558676032399102*^9, 3.5586854255593605`*^9, 3.558700958861228*^9, 
   3.5587530096576557`*^9, 3.5587598958875256`*^9, 3.558762539600737*^9, 
   3.5587630556632547`*^9, 3.5587760550777783`*^9, 3.558779957167965*^9, 
   3.558845910476279*^9, 3.560678084391931*^9, 3.560678122950987*^9, 
   3.560678415348402*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Epot2", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"-", "m2"}], "*", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "g"}]}], "}"}], ".", "r2"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"g", " ", "m2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "l0"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
    RowBox[{"l2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5539170607523775`*^9, 3.553917171156538*^9, 3.5539174129878993`*^9, 
   3.554021598454668*^9, 3.5541892055761585`*^9, 3.5565250648688354`*^9, 
   3.558171350573803*^9, 3.558260287413699*^9, 3.5582618133909802`*^9, 
   3.5582619385611396`*^9, {3.558262437061652*^9, 3.55826244068886*^9}, 
   3.5584282368628583`*^9, 3.5584300104293003`*^9, 3.5584302645318346`*^9, 
   3.558431362875656*^9, 3.558432719792267*^9, {3.558435047575409*^9, 
   3.5584350820343795`*^9}, 3.558435840158742*^9, 3.558435916216092*^9, 
   3.5584361290142636`*^9, 3.5584361628521986`*^9, 3.5586691345545683`*^9, 
   3.558670503125846*^9, 3.5586716841663976`*^9, 3.5586736968935194`*^9, 
   3.558674050486744*^9, 3.5586751233101053`*^9, 3.558675243803997*^9, 
   3.5586760324621058`*^9, 3.558685425623364*^9, 3.5587009589212284`*^9, 
   3.558753009767662*^9, 3.5587598959375286`*^9, 3.5587625396557407`*^9, 
   3.5587630557122574`*^9, 3.5587760551797843`*^9, 3.5587799572659707`*^9, 
   3.5588459105312815`*^9, 3.560678084431931*^9, 3.560678122990987*^9, 
   3.560678415388402*^9}]
}, Open  ]],

Cell["\<\
For the a non moving plate we get the same results as for the static \
identification\
\>", "Text",
 CellChangeTimes->{{3.554021452080296*^9, 3.5540215053133407`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Energy for K3 / the  moving and rotating parts. (paddle,sliders... ..)
r3\tlocation of the CG of the body
v3\tvelocity of the CG of the body
m3\tmass
I3\tMOI for a rotation around the CG for the body
l0 \tpendulum length
l3\tdistance to cog l3=c0+zp\
\>", "Subsubsection",
 CellChangeTimes->{{3.5539170183953176`*^9, 3.553917025745328*^9}, {
  3.5540209156136117`*^9, 3.554020934652701*^9}, {3.558434818849326*^9, 
  3.558434851105171*^9}, {3.560678068789909*^9, 3.5606780730899153`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "l0"}], "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c0", "+", 
         RowBox[{"zp", "[", "t", "]"}]}], ")"}], "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"upsilon", "[", "t", "]"}], "]"}]}]}], ",", 
     "\[IndentingNewLine]", "0", ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "l0"}], "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c0", "+", 
         RowBox[{"zp", "[", "t", "]"}]}], ")"}], "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"upsilon", "[", "t", "]"}], "]"}]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.554020939864999*^9, 3.554020962226278*^9}, {
   3.5540213532736444`*^9, 3.5540213883616514`*^9}, {3.558260275944043*^9, 
   3.5582602789912176`*^9}, {3.558260697519156*^9, 3.558260703150478*^9}, 
   3.560678118077978*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v3", "=", 
  RowBox[{"D", "[", 
   RowBox[{"r3", ",", "t"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5540209920389833`*^9, 3.554020995255167*^9}, 
   3.558428523349244*^9, {3.5584286476203527`*^9, 3.558428649540462*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "l0"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"c0", "+", 
       RowBox[{"zp", "[", "t", "]"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["upsilon", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["zp", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"l0", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["phi", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"c0", "+", 
       RowBox[{"zp", "[", "t", "]"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["upsilon", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["zp", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.55391704845936*^9, 3.553917171006538*^9, 3.5539174128378987`*^9, 
   3.5540209957461953`*^9, 3.5540213915888357`*^9, 3.5540215985636744`*^9, 
   3.554189205867175*^9, 3.5565250651678524`*^9, 3.558171350944824*^9, 
   3.5582602876657133`*^9, 3.558260708476783*^9, 3.5582618137420006`*^9, 
   3.5582619392961817`*^9, {3.5582624373336678`*^9, 3.5582624412308903`*^9}, 
   3.558428237172876*^9, 3.558428525002339*^9, 3.558428650313506*^9, 
   3.558430010540307*^9, 3.558430264642841*^9, 3.558431363022664*^9, 
   3.558432720085284*^9, {3.5584350477084165`*^9, 3.5584350821713877`*^9}, 
   3.558435840395756*^9, 3.558435916425104*^9, 3.558436129139271*^9, 
   3.5584361629632053`*^9, 3.5586691346825757`*^9, 3.5586705032568536`*^9, 
   3.558671684325407*^9, 3.558673696997525*^9, 3.558674050614751*^9, 
   3.558675123494116*^9, 3.5586752439360046`*^9, 3.5586760325731125`*^9, 
   3.5586854257353706`*^9, 3.558700959031228*^9, 3.558753009870668*^9, 
   3.558759896019533*^9, 3.5587625397477455`*^9, 3.5587630557882614`*^9, 
   3.5587760552567883`*^9, 3.558779957356976*^9, 3.5588459106142864`*^9, 
   3.5606780845119314`*^9, 3.5606781230609865`*^9, 3.560678415438402*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ekin3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "m3", "*", 
     RowBox[{"v3", ".", "v3"}]}], "+", 
    RowBox[{
     RowBox[{"1", "/", "2"}], "*", "I3", "*", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "'"}], "[", "t", "]"}], "^", "2"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5540210010885005`*^9, 3.554021008455922*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"I3", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["upsilon", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"m3", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l0", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["phi", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"c0", "+", 
             RowBox[{"zp", "[", "t", "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["upsilon", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["zp", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "2"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "l0"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"phi", "[", "t", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["phi", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"c0", "+", 
             RowBox[{"zp", "[", "t", "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["upsilon", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["zp", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "2"]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.553917054070368*^9, 3.553917171116538*^9, 3.553917412937899*^9, 
   3.554021023698794*^9, 3.554021392620895*^9, 3.5540215986146774`*^9, 
   3.554189206031184*^9, 3.5565250653408623`*^9, 3.5581713511208344`*^9, 
   3.5582602879297285`*^9, 3.5582607087367973`*^9, 3.5582618140120153`*^9, 
   3.5582619396992044`*^9, {3.55826243737867*^9, 3.5582624415139065`*^9}, 
   3.5584282374428916`*^9, 3.55843001059431*^9, 3.5584302646908436`*^9, 
   3.5584313633416824`*^9, 3.558432720433304*^9, {3.5584350477684197`*^9, 
   3.558435082235391*^9}, 3.558435840698773*^9, 3.558435916683119*^9, 
   3.5584361294062862`*^9, 3.5584361630222087`*^9, 3.5586691349295893`*^9, 
   3.558670503593873*^9, 3.5586716849954453`*^9, 3.5586736970535283`*^9, 
   3.5586740509397697`*^9, 3.5586751237801323`*^9, 3.5586752442520227`*^9, 
   3.5586760329031315`*^9, 3.558685426027387*^9, 3.558700959291229*^9, 
   3.5587530101246824`*^9, 3.5587598962845483`*^9, 3.55876253999376*^9, 
   3.5587630560432763`*^9, 3.5587760555018024`*^9, 3.5587799576079903`*^9, 
   3.5588459109433055`*^9, 3.5606780847619314`*^9, 3.560678123120987*^9, 
   3.560678416820405*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Epot3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"-", "m3"}], "*", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "g"}]}], "}"}], ".", "r3"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.554021030360175*^9, 3.554021035679479*^9}}],

Cell[BoxData[
 RowBox[{"g", " ", "m3", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "l0"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"phi", "[", "t", "]"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"upsilon", "[", "t", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{"c0", "+", 
       RowBox[{"zp", "[", "t", "]"}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.5539170607523775`*^9, 3.553917171156538*^9, 3.5539174129878993`*^9, 
   3.5540210361085033`*^9, 3.5540215986666803`*^9, 3.5541892060841875`*^9, 
   3.5565250653988657`*^9, 3.5581713511798377`*^9, 3.5582602879987326`*^9, 
   3.558260708814802*^9, 3.558261814156024*^9, 3.5582619398182116`*^9, {
   3.5582624374396734`*^9, 3.558262441609912*^9}, 3.5584282375648985`*^9, 
   3.558430010654313*^9, 3.5584302647578473`*^9, 3.5584313634986916`*^9, 
   3.558432720562311*^9, {3.5584350478324237`*^9, 3.5584350822973948`*^9}, 
   3.558435840871783*^9, 3.5584359168321276`*^9, 3.55843612947729*^9, 
   3.558436163071212*^9, 3.558669134997594*^9, 3.5586705037418814`*^9, 
   3.5586716858974967`*^9, 3.558673697110532*^9, 3.5586740511667824`*^9, 
   3.558675124135153*^9, 3.558675244476036*^9, 3.558676032980136*^9, 
   3.558685426195397*^9, 3.558700959393229*^9, 3.5587530102786913`*^9, 
   3.5587598963645525`*^9, 3.5587625400517635`*^9, 3.55876305610728*^9, 
   3.558776055557806*^9, 3.558779957663994*^9, 3.558845911002309*^9, 
   3.5606780848119316`*^9, 3.5606781231509867`*^9, 3.560678416930405*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Holonomic constrains", "Section",
 CellChangeTimes->{{3.558429837321399*^9, 3.55842984556087*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r2", "=", 
   RowBox[{"r2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.558429924266372*^9, 3.5584299469506693`*^9}, {
   3.5584303095864115`*^9, 3.5584303296955614`*^9}, 3.558430415478468*^9, 
   3.560678150585026*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v2", "=", 
   RowBox[{"v2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.558430420902778*^9, 3.560678151746027*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ekin2", "=", 
   RowBox[{"Ekin2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5584303503327417`*^9, 3.5584303574481487`*^9}, 
   3.558430424815002*^9, 3.560678152406028*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Epot2", "=", 
   RowBox[{"Epot2", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5584358741136837`*^9, 3.5584359079906216`*^9}, 
   3.560678153256029*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r3", "=", 
   RowBox[{"r3", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.558429916583933*^9, 3.558429922500271*^9}, {
   3.5584303787843695`*^9, 3.5584303889599514`*^9}, 3.558430430519328*^9, 
   3.5606781542760305`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v3", "=", 
   RowBox[{"v3", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.558430392279141*^9, 3.558430393743225*^9}, 
   3.5584304359266376`*^9, 3.5606781550360317`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ekin3", "=", 
   RowBox[{"Ekin3", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5584304424220095`*^9, 3.5584304610870767`*^9}, 
   3.560678155686033*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Epot3", "=", 
   RowBox[{"Epot3", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"upsilon", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{"phi", "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"upsilon", "'"}], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"c", "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.558435896173946*^9, 3.558435905197462*^9}, 
   3.560678156296034*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non potential damping torque", "Section",
 CellChangeTimes->{{3.5584282500086102`*^9, 3.558428266737567*^9}, {
   3.5584306284676504`*^9, 3.55843063527304*^9}, 3.558753026885641*^9, {
   3.5587600184855375`*^9, 3.558760022589772*^9}, {3.5606782097761097`*^9, 
   3.560678222482128*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fnp", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "damping"}], "*", 
     RowBox[{
      RowBox[{"phi", "'"}], "[", "t", "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558430694352419*^9, 3.558430722261015*^9}, 
   3.5584308547725945`*^9, {3.560678217188121*^9, 3.5606782406061535`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Langrange", "Section",
 CellChangeTimes->{3.553916520801289*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "=", 
   RowBox[{"Ekin1", "+", "Ekin2", "+", "Ekin3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5303571364078274`*^9, 3.530357140958088*^9}, {
   3.5304262744502974`*^9, 3.5304262764024086`*^9}, 3.530435782108104*^9, {
   3.5304375476440873`*^9, 3.5304375540674543`*^9}, {3.5538639420746*^9, 
   3.5538639424816236`*^9}, {3.5540215752713423`*^9, 3.5540215772714567`*^9}, 
   3.5584307364688272`*^9, 3.558759911800436*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"V", "=", 
   RowBox[{"Epot1", "+", "Epot2", "+", "Epot3"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.53035715009061*^9, 3.5303571780472093`*^9}, {
   3.530426282986786*^9, 3.530426284706884*^9}, 3.5304357840362144`*^9, {
   3.5304375577956676`*^9, 3.530437562499937*^9}, {3.5538639436586914`*^9, 
   3.5538639448737607`*^9}, {3.5540215801276197`*^9, 3.5540215844388666`*^9}, 
   3.5584307412931037`*^9, {3.5587599132975216`*^9, 3.5587599148566103`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol1", "=", 
   RowBox[{
    RowBox[{"Solve", "[", " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", " ", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"T", ",", 
            RowBox[{
             SuperscriptBox["phi", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "]"}], ",", "t"}], 
         " ", "]"}], " ", "-", " ", 
        RowBox[{"D", "[", 
         RowBox[{"T", ",", 
          RowBox[{"phi", "[", "t", "]"}]}], "]"}], " ", "+", " ", 
        RowBox[{"D", "[", 
         RowBox[{"V", ",", 
          RowBox[{"phi", "[", "t", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
       "\[Equal]", " ", 
       RowBox[{
        RowBox[{"-", "damping"}], "*", 
        RowBox[{
         RowBox[{"phi", "'"}], "[", "t", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"phi", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558261059357852*^9, 3.558261066477259*^9}, {
   3.5582614146111712`*^9, 3.558261505039344*^9}, {3.558261568510974*^9, 
   3.558261572887224*^9}, {3.558261616607725*^9, 3.5582616467104464`*^9}, 
   3.5582624245359354`*^9, {3.5584307641624117`*^9, 3.5584308899836082`*^9}, 
   3.558430967453039*^9, 3.558431046403555*^9, 3.558431208554829*^9, 
   3.558432711067768*^9, 3.558432762036683*^9, {3.558433107658452*^9, 
   3.5584331090835333`*^9}, {3.5584331397472873`*^9, 
   3.5584331458526363`*^9}, {3.5606782579201803`*^9, 3.5606782992462378`*^9}, 
   3.5606783406842966`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"phidotdot", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", "sol1", "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"phi", "[", "t", "]"}], "\[Rule]", "phi"}], ",", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"phi", "'"}], "[", "t", "]"}], "\[Rule]", "phidot"}], ",", 
     "  ", 
     RowBox[{
      RowBox[{"zp", "[", "t", " ", "]"}], "\[Rule]", " ", "zp"}], ",", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["zp", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "zpdot"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"zp", "''"}], "[", "t", "]"}], "\[Rule]", "zpdotdot"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.5582616740660114`*^9, 3.5582617064428635`*^9}, 
   3.5587599554929347`*^9, 3.5587629276679335`*^9, 3.560678306757249*^9, {
   3.560678348915308*^9, 3.56067834981631*^9}, {3.5606784422574425`*^9, 
   3.5606784437274446`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "phidot"}], " ", 
     RowBox[{"(", 
      RowBox[{"damping", "+", 
       RowBox[{"2", " ", "c", " ", "m3", " ", "zpdot", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c", " ", "c0"}], "-", 
          RowBox[{"l0", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "phi"}], "]"}]}]}],
          ")"}]}]}], ")"}]}], "-", 
    RowBox[{"g", " ", "l1", " ", "m1", " ", 
     RowBox[{"Sin", "[", "phi", "]"}]}], "-", 
    RowBox[{"g", " ", "l0", " ", "m2", " ", 
     RowBox[{"Sin", "[", "phi", "]"}]}], "-", 
    RowBox[{"g", " ", "l0", " ", "m3", " ", 
     RowBox[{"Sin", "[", "phi", "]"}]}], "+", 
    RowBox[{"c", " ", "g", " ", "l2", " ", "m2", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"c", " ", "phi"}], "]"}]}], "+", 
    RowBox[{"c", " ", "c0", " ", "g", " ", "m3", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"c", " ", "phi"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "c", " ", "l0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l2", " ", "m2"}], "+", 
       RowBox[{"c0", " ", "m3"}]}], ")"}], " ", 
     SuperscriptBox["phidot", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "-", 
       RowBox[{"c", " ", "phi"}]}], "]"}]}], "-", 
    RowBox[{"l0", " ", "m3", " ", "zpdotdot", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"phi", "-", 
       RowBox[{"c", " ", "phi"}]}], "]"}]}], "+", 
    RowBox[{"c", " ", "m3", " ", "zp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "c", " ", "phidot", " ", "zpdot"}], "+", 
       RowBox[{"g", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"c", " ", "phi"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "l0", " ", 
        SuperscriptBox["phidot", "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"phi", "-", 
          RowBox[{"c", " ", "phi"}]}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"I1", "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "I2"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "I3"}], "+", 
    RowBox[{
     SuperscriptBox["l1", "2"], " ", "m1"}], "+", 
    RowBox[{
     SuperscriptBox["l0", "2"], " ", "m2"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["l2", "2"], " ", "m2"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     SuperscriptBox["c0", "2"], " ", "m3"}], "+", 
    RowBox[{
     SuperscriptBox["l0", "2"], " ", "m3"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "m3", " ", 
     SuperscriptBox["zp", "2"]}], "-", 
    RowBox[{"2", " ", "c", " ", "l0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l2", " ", "m2"}], "+", 
       RowBox[{"c0", " ", "m3"}]}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "phi"}], "]"}]}], "+", 
    RowBox[{"2", " ", "c", " ", "m3", " ", "zp", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"c", " ", "c0"}], "-", 
       RowBox[{"l0", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "c"}], ")"}], " ", "phi"}], "]"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.560678308927252*^9, 3.560678350796311*^9, {3.5606784248754177`*^9, 
   3.560678449288452*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Export to Matlab including Gradients\
\>", "Section",
 CellChangeTimes->{{3.5588484088351765`*^9, 3.55884841046627*^9}, {
  3.560678395625374*^9, 3.5606784056573887`*^9}}],

Cell["\<\
use ctrl + shift + c to copy the formulas to the clipboard to prevent format \
mess\
\>", "Text",
 CellChangeTimes->{{3.560678589128521*^9, 3.5606786188235626`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", "phidotdot", "]"}]], "Input",
 CellChangeTimes->{{3.5588485288950434`*^9, 3.558848538251579*^9}, 
   3.560678378091349*^9, 3.5606784470484495`*^9}],

Cell[BoxData["\<\"(I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.*l2.^2.*m2+c.\
^2.* ...\\n  \
c0.^2.*m3+l0.^2.*m3+c.^2.*m3.*zp.^2+(-2).*c.*l0.*(l2.*m2+c0.*m3).* ...\\n  \
cos(((-1)+c).*phi)+2.*c.*m3.*zp.*(c.*c0+(-1).*l0.*cos(((-1)+c).* ...\\n  \
phi))).^(-1).*((-1).*phidot.*(damping+2.*c.*m3.*zpdot.*(c.*c0+(-1) ...\\n  \
.*l0.*cos(((-1)+c).*phi)))+(-1).*g.*l1.*m1.*sin(phi)+(-1).*g.*l0.* ...\\n  \
m2.*sin(phi)+(-1).*g.*l0.*m3.*sin(phi)+c.*g.*l2.*m2.*sin(c.*phi)+ ...\\n  \
c.*c0.*g.*m3.*sin(c.*phi)+((-1)+c).*c.*l0.*(l2.*m2+c0.*m3).* ...\\n  \
phidot.^2.*sin(phi+(-1).*c.*phi)+(-1).*l0.*m3.*zpdotdot.*sin(phi+( ...\\n  \
-1).*c.*phi)+c.*m3.*zp.*((-2).*c.*phidot.*zpdot+g.*sin(c.*phi)+(( ...\\n  \
-1)+c).*l0.*phidot.^2.*sin(phi+(-1).*c.*phi)));\\n\"\>"], "Output",
 CellChangeTimes->{
  3.5588539311140327`*^9, {3.560678430746426*^9, 3.560678450899454*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"phidotdot", ",", "phi"}], "]"}], "]"}], ",", "\"\<df2dx1\>\""}],
   "]"}]], "Input",
 CellChangeTimes->{{3.558853860660003*^9, 3.5588539112538967`*^9}, 
   3.558853946079889*^9, {3.5588540399342575`*^9, 3.558854044814536*^9}}],

Cell[BoxData["\<\"df2dx1=(I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.*l2.^\
2.*m2+c.^2.* ...\\n  \
c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2).*c.* ...\\n  \
l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).^(-2).*((I1+c.^2.* ...\\n  \
I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.*l2.^2.*m2+c.^2.*c0.^2.*m3+ ...\\n  \
l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2).*c.*l0.*(l2.* ...\\n  \
m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).*((-1).*g.*(l1.*m1+l0.*(m2+ ...\\n  \
m3)).*cos(phi)+c.^2.*g.*(l2.*m2+m3.*(c0+zp)).*cos(c.*phi)+(-1).*(( ...\\n  \
-1)+c).*l0.*(((-1).*c.*phidot.^2.*(l2.*m2+m3.*(c0+zp))+c.^2.* ...\\n  \
phidot.^2.*(l2.*m2+m3.*(c0+zp))+(-1).*m3.*zpdotdot).*cos(phi+(-1) ...\\n  \
.*c.*phi)+2.*c.*m3.*phidot.*zpdot.*sin(((-1)+c).*phi)))+(-2).*(( ...\\n  \
-1)+c).*c.*l0.*(l2.*m2+m3.*(c0+zp)).*sin(((-1)+c).*phi).*((-1).* ...\\n  \
phidot.*(damping+2.*c.*m3.*zpdot.*(c.*c0+(-1).*l0.*cos(((-1)+c).* ...\\n  \
phi)))+(-1).*g.*l1.*m1.*sin(phi)+(-1).*g.*l0.*m2.*sin(phi)+(-1).* ...\\n  \
g.*l0.*m3.*sin(phi)+c.*g.*l2.*m2.*sin(c.*phi)+c.*c0.*g.*m3.*sin( ...\\n  \
c.*phi)+((-1)+c).*c.*l0.*(l2.*m2+c0.*m3).*phidot.^2.*sin(phi+(-1) ...\\n  \
.*c.*phi)+(-1).*l0.*m3.*zpdotdot.*sin(phi+(-1).*c.*phi)+c.*m3.* ...\\n  \
zp.*(g.*sin(c.*phi)+phidot.*((-2).*c.*zpdot+((-1)+c).*l0.*phidot.* ...\\n  \
sin(phi+(-1).*c.*phi)))));\\n\"\>"], "Output",
 CellChangeTimes->{3.5588539599566827`*^9, 3.558854057924286*^9, 
  3.56067843349643*^9, 3.560678464715556*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"phidotdot", ",", "phidot"}], "]"}], "]"}], ",", 
   "\"\<df2dx2\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5588539935186024`*^9, 3.558853997781846*^9}, {
  3.558854052036949*^9, 3.5588540529810033`*^9}}],

Cell[BoxData["\<\"df2dx2=(-1).*(I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.\
*l2.^2.*m2+ ...\\n  \
c.^2.*c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2) ...\\n  \
.*c.*l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).^(-1).*( ...\\n  \
damping+2.*c.^2.*c0.*m3.*zpdot+2.*c.^2.*m3.*zp.*zpdot+(-2).*c.* ...\\n  \
l0.*m3.*zpdot.*cos(((-1)+c).*phi)+(-2).*((-1)+c).*c.*l0.*phidot.*( ...\\n  \
l2.*m2+m3.*(c0+zp)).*sin(phi+(-1).*c.*phi));\\n\"\>"], "Output",
 CellChangeTimes->{3.558854012807706*^9, 3.5588540585403214`*^9, 
  3.560678528907436*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"phidotdot", ",", "zp"}], "]"}], "]"}], ",", "\"\<df2dx3\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.558853967503114*^9, 3.5588539676301217`*^9}, {
  3.5588540008860235`*^9, 3.558854001015031*^9}, {3.558854057349253*^9, 
  3.5588540585863237`*^9}}],

Cell[BoxData["\<\"df2dx3=c.*m3.*(I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^\
2.*l2.^2.*m2+ ...\\n  \
c.^2.*c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2) ...\\n  \
.*c.*l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).^(-2).*((I1+ ...\\n  \
c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.*l2.^2.*m2+c.^2.* ...\\n  \
c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2).*c.* ...\\n  \
l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).*(g.*sin(c.*phi)+ ...\\n  \
phidot.*((-2).*c.*zpdot+((-1)+c).*l0.*phidot.*sin(phi+(-1).*c.* ...\\n  \
phi)))+(-2).*(c.*(c0+zp)+(-1).*l0.*cos(((-1)+c).*phi)).*((-1).* ...\\n  \
phidot.*(damping+2.*c.*m3.*zpdot.*(c.*c0+(-1).*l0.*cos(((-1)+c).* ...\\n  \
phi)))+(-1).*g.*l1.*m1.*sin(phi)+(-1).*g.*l0.*m2.*sin(phi)+(-1).* ...\\n  \
g.*l0.*m3.*sin(phi)+c.*g.*l2.*m2.*sin(c.*phi)+c.*c0.*g.*m3.*sin( ...\\n  \
c.*phi)+((-1)+c).*c.*l0.*(l2.*m2+c0.*m3).*phidot.^2.*sin(phi+(-1) ...\\n  \
.*c.*phi)+(-1).*l0.*m3.*zpdotdot.*sin(phi+(-1).*c.*phi)+c.*m3.* ...\\n  \
zp.*(g.*sin(c.*phi)+phidot.*((-2).*c.*zpdot+((-1)+c).*l0.*phidot.* ...\\n  \
sin(phi+(-1).*c.*phi)))));\\n\"\>"], "Output",
 CellChangeTimes->{3.558854017562978*^9, 3.558854062326538*^9, 
  3.560678527287434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"phidotdot", ",", "zpdot"}], "]"}], "]"}], ",", 
   "\"\<df2dx4\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5588539700862617`*^9, 3.5588539709183097`*^9}, {
  3.5588540036781836`*^9, 3.55885400379819*^9}, {3.558854061597496*^9, 
  3.558854063046579*^9}}],

Cell[BoxData["\<\"df2dx4=(-2).*c.*m3.*phidot.*(c.*(c0+zp)+(-1).*l0.*cos(((-1)+\
c).*phi)).*( ...\\n  \
I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*m2+c.^2.*l2.^2.*m2+c.^2.* ...\\n  \
c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.*zp.^2+(-2).*c.* ...\\n  \
l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).^(-1);\\n\"\>"], "Output",
 CellChangeTimes->{3.5588540178919964`*^9, 3.5588540648176804`*^9, 
  3.5606785177774115`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ToMatlab", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"D", "[", 
     RowBox[{"phidotdot", ",", "zpdotdot"}], "]"}], "]"}], ",", 
   "\"\<df2du\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.558853973078433*^9, 3.5588539745335164`*^9}, {
  3.5588540061823263`*^9, 3.5588540077834177`*^9}, {3.5588540673108225`*^9, 
  3.5588540679098573`*^9}}],

Cell[BoxData["\<\"df2du=(-1).*l0.*m3.*(I1+c.^2.*I2+c.^2.*I3+l1.^2.*m1+l0.^2.*\
m2+c.^2.* ...\\n  \
l2.^2.*m2+c.^2.*c0.^2.*m3+l0.^2.*m3+2.*c.^2.*c0.*m3.*zp+c.^2.*m3.* ...\\n  \
zp.^2+(-2).*c.*l0.*(l2.*m2+m3.*(c0+zp)).*cos(((-1)+c).*phi)).^(-1) ...\\n  \
.*sin(phi+(-1).*c.*phi);\\n\"\>"], "Output",
 CellChangeTimes->{3.5588540181390104`*^9, 3.558854068530893*^9, 
  3.560678520472418*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{944, 1012},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.9599999999999, 842.04}},
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Output"]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (32-bit) (February 23, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 115, 1, 83, "Title"],
Cell[697, 25, 136, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[858, 32, 97, 1, 71, "Section"],
Cell[958, 35, 55289, 912, 574, "Text"],
Cell[56250, 949, 198, 4, 29, "Text"],
Cell[56451, 955, 17666, 294, 291, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74154, 1254, 193, 3, 71, "Section"],
Cell[74350, 1259, 161, 3, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74548, 1267, 220, 3, 71, "Section"],
Cell[CellGroupData[{
Cell[74793, 1274, 483, 11, 123, "Subsubsection"],
Cell[75279, 1287, 455, 14, 31, "Input"],
Cell[CellGroupData[{
Cell[75759, 1305, 188, 4, 31, "Input"],
Cell[75950, 1311, 908, 21, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76895, 1337, 397, 13, 31, "Input"],
Cell[77295, 1352, 1384, 26, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78716, 1383, 329, 9, 31, "Input"],
Cell[79048, 1394, 1228, 20, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[80325, 1420, 460, 12, 123, "Subsubsection"],
Cell[80788, 1434, 728, 23, 72, "Input"],
Cell[CellGroupData[{
Cell[81541, 1461, 103, 3, 31, "Input"],
Cell[81647, 1466, 2070, 45, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83754, 1516, 355, 12, 31, "Input"],
Cell[84112, 1530, 2074, 47, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86223, 1582, 245, 8, 31, "Input"],
Cell[86471, 1592, 1395, 26, 30, "Output"]
}, Open  ]],
Cell[87881, 1621, 177, 4, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88095, 1630, 498, 11, 123, "Subsubsection"],
Cell[88596, 1643, 1114, 32, 72, "Input"],
Cell[CellGroupData[{
Cell[89735, 1679, 245, 5, 31, "Input"],
Cell[89983, 1686, 2754, 64, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[92774, 1755, 423, 13, 31, "Input"],
Cell[93200, 1770, 3383, 79, 69, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96620, 1854, 311, 9, 31, "Input"],
Cell[96934, 1865, 1525, 29, 30, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98520, 1901, 104, 1, 71, "Section"],
Cell[98627, 1904, 639, 19, 31, "Input"],
Cell[99269, 1925, 533, 17, 31, "Input"],
Cell[99805, 1944, 593, 18, 31, "Input"],
Cell[100401, 1964, 571, 18, 31, "Input"],
Cell[100975, 1984, 639, 19, 31, "Input"],
Cell[101617, 2005, 587, 18, 31, "Input"],
Cell[102207, 2025, 571, 18, 31, "Input"],
Cell[102781, 2045, 567, 18, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[103385, 2068, 292, 4, 71, "Section"],
Cell[103680, 2074, 342, 9, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[104059, 2088, 70, 1, 71, "Section"],
Cell[104132, 2091, 461, 8, 31, "Input"],
Cell[104596, 2101, 488, 8, 31, "Input"],
Cell[105087, 2111, 1626, 39, 72, "Input"],
Cell[CellGroupData[{
Cell[106738, 2154, 946, 25, 31, "Input"],
Cell[107687, 2181, 3658, 107, 117, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[111394, 2294, 181, 4, 71, "Section"],
Cell[111578, 2300, 175, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[111778, 2308, 187, 3, 31, "Input"],
Cell[111968, 2313, 861, 12, 221, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112866, 2330, 344, 8, 31, "Input"],
Cell[113213, 2340, 1465, 20, 373, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[114715, 2365, 325, 8, 31, "Input"],
Cell[115043, 2375, 555, 8, 145, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115635, 2388, 371, 9, 31, "Input"],
Cell[116009, 2399, 1212, 17, 316, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117258, 2421, 374, 9, 31, "Input"],
Cell[117635, 2432, 420, 6, 107, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118092, 2443, 381, 9, 31, "Input"],
Cell[118476, 2454, 388, 6, 107, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
